@@ -714,7 +714,8 @@ sub ctest {
     if (defined($out) and !$result) {
         chomp $out;
         $ok = $out =~ /$expected/;
-        unless ($ok) { #crosscheck uncompiled
+	diag($out);
+	unless ($ok) { #crosscheck uncompiled
             my $out1 = `$runperl $name.pl`;
             unless ($out1 =~ /$expected/) {
                 ok(1, "skip also fails uncompiled $todo");
@@ -726,6 +727,7 @@ sub ctest {
           TODO: {
                 local $TODO = $todo;
                 ok ($out =~ /$expected/);
+		diag($out);
             }
         } else {
             ok ($out =~ /$expected/, $todo);
@@ -809,6 +811,7 @@ sub todo_tests_default {
 	#15,21,27,30,41-45,50,103,105
 	push @todo, (21,30,46,50,103,105);
 	push @todo, (15)    if $] < 5.008008;
+	push @todo, (15)    if $] >= 5.012 and $] < 5.015 and $ITHREADS;
 	push @todo, (104,105) if $] < 5.007; # leaveloop, no cxstack
 	push @todo, (3,7,15,41,44,45) if $] > 5.008 and $] <= 5.008005;
         push @todo, (42,43) if $] > 5.008 and $] <= 5.008005 and !$ITHREADS;
@@ -826,7 +829,7 @@ sub todo_tests_default {
 	push @todo, (27)    if $] <= 5.008008;
 	push @todo, (25)    if $] >= 5.011004 and $DEBUGGING and $ITHREADS;
 	push @todo, (3,4)   if $] >= 5.011004 and $ITHREADS;
-	push @todo, (49)    if $] >= 5.013009 and !$ITHREADS;
+	#push @todo, (49)    if $] >= 5.013009 and !$ITHREADS;
     }
     push @todo, (48)   if $] > 5.007 and $] < 5.009 and $^O =~ /MSWin32|cygwin/i;
     return @todo;
